<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fi_FI">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>Selaimen ulkopuolellakin on elämää!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Versionumero: %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 on ilmainen ohjelma,mutta sen kehittäminen vie kallista aika.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Voit tukea  %2n kehityksen jatkumista tekemällä &lt;a href=&apos;%1&apos;&gt;lahjoituksen&lt;/a&gt;.</translation>
    </message>
    <message>
        <source>Report bugs and send in your ideas to %1</source>
        <translation>Ilmoita bugit ja kerro ideasi osoitteeseen %1</translation>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>Kuvakkeen suunnitteli %1.</translation>
    </message>
    <message>
        <source>Compact mode contributed by %1.</source>
        <translation>Kompaktin tilan teki %1.</translation>
    </message>
    <message>
        <source>HTTP proxy support contributed by %1.</source>
        <translation>HTTP-välityspalvelintuen teki %1.</translation>
    </message>
    <message>
        <source>Translated by %1</source>
        <translation>Käännöksen teki %1</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Julkaistu &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt; -lisenssillä</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Sulje</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Tietoja</translation>
    </message>
    <message>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation>Mitä olet aina halunnut tietää %1sta, muttet ole koskaan kehdannut kysyä</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Tyhjennä</translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>bytes</source>
        <translation>tavua</translation>
    </message>
    <message>
        <source>KB</source>
        <translation>Kt</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>Mt</translation>
    </message>
    <message>
        <source>bytes/sec</source>
        <translation>tavua/sekunnissa</translation>
    </message>
    <message>
        <source>KB/sec</source>
        <translation>Kt/s</translation>
    </message>
    <message>
        <source>MB/sec</source>
        <translation>Mt/s</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>sekunttia</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minuuttia</translation>
    </message>
    <message>
        <source>%4 %5 remaining</source>
        <translation>%4 %5 jäljellä</translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message numerus="yes">
        <source>%n Download(s)</source>
        <translation>
            <numerusform>%n Lataus(ta)</numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>This is just the demo version of %1.</source>
        <translation>Tämä on vain kokeilu versio %1sta.</translation>
    </message>
    <message>
        <source>It can only download videos shorter than %1 minutes so you can test the download functionality.</source>
        <translation>Voit ladata vain videoita jotka ovat lyhyempiä kuin %1 minuuttia, jotta voit testata lataus ominaisuutta.</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Jatka</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Hanki täysi versio</translation>
    </message>
</context>
<context>
    <name>DownloadSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Vaihda sijaintia...</translation>
    </message>
    <message>
        <source>Choose the download location</source>
        <translation>Valitse latausten sijainti</translation>
    </message>
    <message>
        <source>Download location changed.</source>
        <translation>Lataus sijaintia on muutettu.</translation>
    </message>
    <message>
        <source>Current downloads will still go in the previous location.</source>
        <translation>Nykyiset lataukset menevät vanhaan sijaintiin.</translation>
    </message>
    <message>
        <source>Downloading to: %1</source>
        <translation>Ladataan kansioon: %1</translation>
    </message>
</context>
<context>
    <name>DownloadView</name>
    <message>
        <source>Downloads</source>
        <translation>Lataukset</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation>Toista</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Keskeytä</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>Toista/Keskeytä</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Pysäytä</translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation>Pysäytä toisto nykyisen kappaleen jälkeen</translation>
    </message>
    <message>
        <source>Next track</source>
        <translation>Seuraava kappale</translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation>Edellinen kappale</translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation>Lisää äänen voimakkuutta</translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation>Vähennä äänen voimakkuutta</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Mykistä</translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation>Kelaa eteenpäin</translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation>Kelaa taaksepäin</translation>
    </message>
</context>
<context>
    <name>ListModel</name>
    <message>
        <source>Searching...</source>
        <translation>Etsitään...</translation>
    </message>
    <message>
        <source>Show %1 More</source>
        <translation>Näytä %1 lisää</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>Ei videoita</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>Ei enempää videoita</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Pysäytä</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>Pysäytä toisto ja palaa hakuruutuun</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>&amp;Hyppää yli</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>Siirry seuraavaan videoon</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Keskeytä</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>Keskeytä toisto</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Kokoruutu</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Siirry kokoruututilaan</translation>
    </message>
    <message>
        <source>&amp;Compact mode</source>
        <translation>&amp;Kompakti tila</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>Piilota toistolista sekä työkalupalkki</translation>
    </message>
    <message>
        <source>Open the &amp;YouTube page</source>
        <translation>Avaa &amp;Youtube -sivu</translation>
    </message>
    <message>
        <source>Go to the YouTube video page and pause playback</source>
        <translation>Keskeytä toisto ja mene videon YouTube -sivulle</translation>
    </message>
    <message>
        <source>Copy the YouTube &amp;link</source>
        <translation>Kopio YouTube -&amp;linkki</translation>
    </message>
    <message>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation>Kopio nykyisen videon YouTube -linkki leikepöydälle</translation>
    </message>
    <message>
        <source>Copy the video stream &amp;URL</source>
        <translation>Kopioi videovirran osoite (&amp;URL)</translation>
    </message>
    <message>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation>Kopioi nykyisen videvirran osoite (URL) leikepöydälle</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Poista</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>Poista valitut videot toistolistalta</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Siirrä &amp;Ylös</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>Siirrä valitut videot ylemmäksi toistolistalla</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Sirrä &amp;Alas</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>Siirrä valitut videot alemmaksi toistolistalla</translation>
    </message>
    <message>
        <source>&amp;Clear recent keywords</source>
        <translation type="obsolete">&amp;Poista viimeisimmät hakusanat</translation>
    </message>
    <message>
        <source>Clear the search history. Cannot be undone.</source>
        <translation>Tyhjennä hakuhistoria. Tätä toimintoa ei voi kumota.</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Lopeta</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Näkemiin</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>&amp;Nettisivusto</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 netissä</translation>
    </message>
    <message>
        <source>Make a &amp;donation</source>
        <translation>Tee &amp;lahjoitus</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Tue %1n jatkokehitystä</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Tietoja</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Tietoja %1sta</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Etsi</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Mykistä ääni</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>&amp;Sovellus</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>&amp;Toistolista</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>&amp;Video</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Apua</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Paina näppäinyhdistelmää %1 nostaaksesi tai %2 laskeaksesi äänenvoimakkuutta</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Avataan kohdetta %1</translation>
    </message>
    <message>
        <source>Fatal error: %1</source>
        <translation>Kohtalokas virhe: %1</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Virhe: %1</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;Toista</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>Jatka toistoa</translation>
    </message>
    <message>
        <source>Exit &amp;Full Screen</source>
        <translation>Poistu &amp;kokoruudun tilasta</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Aikaa jäljellä: %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Äänentaso: %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Ääni on mykistetty</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Ääni ei ole mykistetty</translation>
    </message>
    <message>
        <source>Maximum video definition set to %1</source>
        <translation>Korkein videonlaatu on rajoitettu tarkkuteen %1</translation>
    </message>
    <message>
        <source>Your privacy is now safe</source>
        <translation>Yksityisyytesi on nyt turvattu</translation>
    </message>
    <message>
        <source>&amp;Downloads</source>
        <translation>&amp;Lataukset</translation>
    </message>
    <message>
        <source>Show details about video downloads</source>
        <translation>Näytä tietoja latauksista</translation>
    </message>
    <message>
        <source>&amp;Download</source>
        <translation>&amp;Lataa</translation>
    </message>
    <message>
        <source>Download the current video</source>
        <translation>Lataa nykyinen video</translation>
    </message>
    <message>
        <source>Do you want to exit %1 with a download in progress?</source>
        <translation>Tahdotko lopettaa vaikka %1 lataus(ta) on kesken?</translation>
    </message>
    <message>
        <source>If you close %1 now, this download will be cancelled.</source>
        <translation>Jos suljet %1n nyt niin tämä lataus keskeytetään.</translation>
    </message>
    <message>
        <source>Close and cancel download</source>
        <translation>Sulje ja keskeytä lataus</translation>
    </message>
    <message>
        <source>Wait for download to finish</source>
        <translation>Odota latauksen valmistumista</translation>
    </message>
    <message>
        <source>Downloads complete</source>
        <translation>Lataukset ovat valmistuneet</translation>
    </message>
    <message>
        <source>&amp;Clear recent searches</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>Most relevant</source>
        <translation>Osuvin</translation>
    </message>
    <message>
        <source>Most recent</source>
        <translation>Viimeisin</translation>
    </message>
    <message>
        <source>Most viewed</source>
        <translation>Katsotuin</translation>
    </message>
    <message>
        <source>You can now paste the YouTube link into another application</source>
        <translation>Voit nyt liittää YouTube-linkin johonkin toiseen sovellukseen</translation>
    </message>
    <message>
        <source>You can now paste the video stream URL into another application</source>
        <translation>Voit nyt liittää videovirran osoitteen (URL) johonkin toiseen sovellukseen</translation>
    </message>
    <message>
        <source>The link will be valid only for a limited time.</source>
        <translation>Osoite on käytössä vain rajoitetun ajan.</translation>
    </message>
    <message>
        <source>You&apos;re watching &quot;%1&quot;</source>
        <translation type="obsolete">Nyt pyörii &quot;%1&quot;</translation>
    </message>
    <message>
        <source>This is just the demo version of %1.</source>
        <translation>Tämä on vain %1n kokeiluversio.</translation>
    </message>
    <message>
        <source>It allows you to test the application and see if it works for you.</source>
        <translation>Voit kokeilla ohjelmaa nähdäksesi että toimiiko se.</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Jatka</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Hanki täysi versio</translation>
    </message>
    <message>
        <source>Downloading %1</source>
        <translation>Ladataan %1ta/tä</translation>
    </message>
</context>
<context>
    <name>NetworkAccess</name>
    <message>
        <source>Network error: %1</source>
        <translation>Verkkovirhe: %1</translation>
    </message>
</context>
<context>
    <name>PrettyItemDelegate</name>
    <message>
        <source>%1 views</source>
        <translation>Katsottu %1 kertaa</translation>
    </message>
    <message>
        <source>%1 of %2 (%3) ? %4</source>
        <translation type="obsolete">%1  %2 (%3)sta ? %4</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>Valmistellaan</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Epäonnistui</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Valmis</translation>
    </message>
    <message>
        <source>Stopped</source>
        <translation>Pysäytetty</translation>
    </message>
    <message>
        <source>Stop downloading</source>
        <translation>Pysäytä lataus</translation>
    </message>
    <message>
        <source>Show in %1</source>
        <translation>Avaa %1ssa/ssä</translation>
    </message>
    <message>
        <source>Open parent folder</source>
        <translation>Avaa yläkansio</translation>
    </message>
    <message>
        <source>Restart downloading</source>
        <translation>Käynnistä lataus uudelleen</translation>
    </message>
    <message>
        <source>%1 of %2 (%3) — %4</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Etsi</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Tervetuloa &lt;a href=&apos;%1&apos;&gt;%2en&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Enter a keyword to start watching videos.</source>
        <translation type="obsolete">Anna hakusana aloittaaksesi videoiden katselu.</translation>
    </message>
    <message>
        <source>Watch</source>
        <translation>Katso</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>Viimeisimmät hakusanat</translation>
    </message>
    <message>
        <source>A new version of %1 is available. Please &lt;a href=&apos;%2&apos;&gt;update to version %3&lt;/a&gt;</source>
        <translation>Uusi versio %1sta on saatavilla. &lt;a href=&apos;%2&apos;&gt;Päivitäthän versioon %3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>Tee olosi kotoisaksi</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation type="unfinished">Hanki täysi versio</translation>
    </message>
    <message>
        <source>Enter</source>
        <extracomment>&quot;Enter&quot;, as in &quot;type&quot;. The whole frase says: &quot;Enter a keyword to start watching videos&quot;</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>a keyword</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>a channel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>to start watching videos.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Recent channels</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Video</name>
    <message>
        <source>Network error: %1 for %2</source>
        <translation>Verkkovirhe: &quot;%1&quot; &quot;%2&quot;lle</translation>
    </message>
    <message>
        <source>Cannot get video stream for %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
